
/* General font selection. This is the place to adjust the font size for the
 * directory browser area. */
html, body, form, fieldset, table, tr, td, img {
    font-family:Arial,helvetica,sans-serif;
    font-size: 14px;
}

/* Servers page. Each is a p */
p.cdserver {
    margin: 7px 0px 0px 0px;
}

a {
    text-decoration: none;
}

body {margin: 0px 0px 0px 0px;}

/* The current path indicator is an ul inside a browsepath div inside
   the fixedheader div */
div#fixedheader {
    position: fixed;
    top:0;
    left:0;
    width:100%;
    padding: 0px;
}

/* https://stackoverflow.com/questions/40121151/sticky-header-css-when-header-is-unknown-height
 Adding an invisible non-fixed header with the same content allows the rest
 of the content to move down when the lines in the fixed header wrap and its
 height increases (so that the top-margin is not enough) 
*/
div#hiddenheader {
    visibility: hidden;
    padding: 0px;
}

div#browsepath {
    font-size: 80%;
    font-weight: bold;
    /* margin: 0px 0px 10px 0px;*/
}

#browsepath ul {
    list-style-type: none;
    margin: 0;
    padding: 0;
}

#browsepath li {
    margin: 0 0 0 3px;
    float: left;
}

/* The 'jump to initial' list */
div.alphalist {
    margin: 0px 0px 0px 3px;
    padding: 0px;
}


/** Directory listing */

/*** Albums displayed as a field of covers */
#thumbnailsdiv table {
    display: inline-table;
}
#thumbnailsdiv {
    margin-bottom: 25px;
}

.ct_albcovertable {
    margin: 0.5em;
}
.ct_albcovertt {
    white-space: nowrap;
    overflow: hidden;
}
.ct_albcoverartist {
    white-space: nowrap;
    overflow: hidden;
}

/*** List section (albums and tracks or tracks only) */
/* The table id is entrylist */
#entrylist {
    clear: both;
    width: 100%;
    margin-top: -1.5em;
/*    table-layout: fixed;*/
}

/* The table begins with a colgroup, with the following column
 classes. I was not able to do anything really useful with setting
 the widths, I find that the automatic approach is always
 better. This might be different if overflow: and text-overflow:
 worked, but they don't appear to. So the following is commented out
 by default. */
/*
.coltracknumber {
    width: 4em;
}
.coltitle {
  font-size: 50%;
  width: 30%;
}
.colartist {
  width: 30%;
}
.colalbum {
  width: 30%;
}
.colduration {
  width: 6%;
}
*/

/* Styles for the directory list cells */
.tk_tracknum {
    vertical-align: top;
    width: 1em;
}
.tk_title {
    vertical-align: top;
    margin-left: 5px;
}
.tk_artist {
    vertical-align: top;
    align: left;
    margin-left: 5px;
}
.tk_album {
    vertical-align: top;
    margin-left: 5px;
/* Could not get this to work, 
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; */
}
.tk_duration {
    vertical-align: top;
    margin-left: 5px;
}

table.albumheader {
    margin-top: 10px;
}
.albheadertitle {
    font-size: 110%;
    font-weight: bold;
}

div.playermeta {
    text-align: center;
    vertical-align: middle;
}
.playertitle {
    font-size: 110%;
    font-weight: bold;
}
.playerartist {
    font-size: 90%;
}
.playeralbum {
}
