/* Dark version of the dir browser colors */

html {
    background-color: #3c3c3c;
    color: #D8D8D8;
    selection-background-color: #424e72;
}

div#fixedheader {
    background-color: #3c3c3c;
}
div#browsepath {
    background-color: #3c3c3c;
}

a:link {
    color: #D8D8D8;
}

/* Alternate colours for the directory list table */
#entrylist tr:nth-child(even) {
    background: #242424;
}
#entrylist td:empty {
    background: #3c3c3c;
    color: #D8D8D8;
}
#entrylist tr:nth-child(odd) {
    background-color: #3c3c3c;
    color: #D8D8D8;
}

.albumheader {
    background-color: #3c3c3c;
}
